/**
   @version 1.0 06-05-2008
   @author Agustin J. Gonzalez
*/

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.imageio.*;
import java.io.*;
import java.awt.image.*;

/**
   A panel with two tanks and a control system. A simulation to practice 
   with applets.
*/
public class PlantPanel extends JPanel
{  
   public PlantPanel()
   {  
      setLayout(new BorderLayout());
      menuPanel= new Box(BoxLayout.X_AXIS);
      menuPanel.setBorder(new EmptyBorder(5,3,1,3));
      view= new PlantView();
      view.setPreferredSize(new Dimension(700,400));
      
      dt=0.05F; // 50 ms is the delta t of the simulation. 
      TimePace timer = new TimePace(this);
      menuPanel.add(timer.getGUI());
      menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
      infoSpace = timer.getPanel();
      infoSpace.setLocation(0,0);
      
      tank1= new Tank(new Point(180,130), view, 1);
      menuPanel.add(tank1.getGUI());
      menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
      infoTank1 = tank1.getPanel();
      infoTank1.setLocation(0,100);
      view.addEquipment(tank1); 
      
      Tank tank2= new Tank(new Point(240,235), view, 2);
      menuPanel.add(tank2.getGUI());
      menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
      infoTank2 = tank2.getPanel();
      infoTank2.setLocation(0,200);
      view.addEquipment(tank2);
      
      tank1.setReceiver(tank2);
      
      Controller control = new Controller(new Point(50,270), tank2);
      view.addEquipment(control);
      menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
      menuPanel.add(control.getGUI());
      infoController = control.getPanel();
      infoController.setLocation(420,260);
      
      
      alarm = new Alarma();
      view.addEquipment(alarm);
      
      graph1 = new grafico(300,110,tank1);
      menuPanel.add(graph1.getGUI());
      menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
      view.addEquipment(graph1);

      graph2 = new grafico(350,230,tank2,control);
      menuPanel.add(graph2.getGUI());
      menuPanel.add(Box.createRigidArea(new Dimension(10,0)));
      view.addEquipment(graph2);

      add(graph1.getPanel1());
      add(graph2.getPanel1());
      add(graph1.getPanel2());
      add(graph2.getPanel2());
      add(infoSpace);
      add(infoController);
      add(infoTank1);
      add(infoTank2);
      add(menuPanel, BorderLayout.NORTH);
      add(view, BorderLayout.CENTER);
      
      timer.start();
   }
   public void simulationTick(){
	   view.timeTick(dt);
	   view.repaint();
	   if(tank1.getLevel() == 0) {
	       alarm.start();
	   }
	   else alarm.stop();
   }
   

   
   private JComponent menuPanel;
   private JPanel infoTank1,infoTank2,infoController,infoSpace;
   private Tank tank1;
   private PlantView view;
   private float dt;  
   private Alarma alarm;
   private grafico graph1;
   private grafico graph2;
}
